@@ -3,25 +3,7 @@ use quote::quote;
 use syn::parse::Parser;
 use syn::{parse, parse_macro_input, ItemStruct};
 
-#[proc_macro_attribute]
-pub fn interval_mgr(args: TokenStream, input: TokenStream) -> TokenStream {
-    let mut item_struct = parse_macro_input!(input as ItemStruct);
-    let _ = parse_macro_input!(args as parse::Nothing);
-
-    if let syn::Fields::Named(ref mut fields) = item_struct.fields {
-        fields.named.push(
-            syn::Field::parse_named
-                .parse2(quote! { pub interval_mgr: IntervalTimerMgr })
-                .unwrap(),
-        );
-    }
-
-    return quote! {
-        #item_struct
-    }
-    .into();
-}
-
+/// Implement WorldTime
 #[proc_macro_attribute]
 pub fn world_time(args: TokenStream, input: TokenStream) -> TokenStream {
     let mut item_struct = parse_macro_input!(input as ItemStruct);
@@ -37,7 +19,7 @@ pub fn world_time(args: TokenStream, input: TokenStream) -> TokenStream {
     }
 
     return quote! {
-        use std::sync::atomic::AtomicI64;
+        use std::sync::atomic::{AtomicI64, Ordering};
         use rollo::server::world::WorldTime;
         #item_struct
 
